@@ -65,7 +65,7 @@
 #include "multipleview.h"
 #include "wqprintdialogpage.h"
 #include "prefs.h"
-#include "version.h"
+#include "kwordquiz_version.h"
 
 KWordQuizApp::KWordQuizApp(QWidget*):KXmlGuiWindow(0)
 {
@@ -440,17 +440,13 @@ void KWordQuizApp::initActions()
   configApp = KStandardAction::preferences(this, SLOT(slotConfigure()), actionCollection());
   configApp->setWhatsThis(i18n("Specifies preferences for the vocabulary editor and quiz sessions"));
   configApp->setToolTip(configApp->whatsThis());
-  configApp->setToolTip(configApp->whatsThis());
-
-  charMapper = new QSignalMapper(this);
-  connect(charMapper, SIGNAL(mapped(int)), this, SLOT(slotInsertChar(int)));
+  configApp->setStatusTip(configApp->whatsThis());
 
   for (int i = 1; i <=9; ++i) {
     a = actionCollection()->addAction(QStringLiteral("char_%1").arg(QString::number(i)));
     a->setText(i18n("Special Character <numid>%1</numid>", i));
     actionCollection()->setDefaultShortcut(a, QKeySequence(QStringLiteral("Ctrl+%1").arg(QString::number(i))));
-    connect(a, SIGNAL(triggered(bool)), charMapper, SLOT(map()));
-    charMapper->setMapping(a, i);
+    connect(a, &QAction::triggered, this, [this, i] () { slotInsertChar(i); });
   }
 
   updateSpecialCharIcons();
@@ -475,7 +471,7 @@ void KWordQuizApp::initStatusBar()
 void KWordQuizApp::initDocument()
 {
   m_doc = new KEduVocDocument(this);
-  m_doc->setGenerator(QStringLiteral("kwordquiz %1").arg(KWQ_VERSION));
+  m_doc->setGenerator(QStringLiteral("kwordquiz %1").arg(KWORDQUIZ_VERSION_STRING));
   ///@todo New kvtml documents have a locale setting which should contain the language they are written in.
   /* it would be nice to support that somehow. get hot new stuff for KHangman and KAnagram already uses this. */
   m_doc->appendIdentifier();
@@ -750,6 +746,8 @@ bool KWordQuizApp::queryClose()
     if (m_dirWatch->contains(m_doc->url().toLocalFile()))
       m_dirWatch->removeFile(m_doc->url().toLocalFile());
   saveOptions();
+  // Close the current document to get rid of its lock file
+  m_doc->close();
   return completed;
 }
 
@@ -979,6 +977,8 @@ void KWordQuizApp::slotFileQuit()
       // the window and the application stay open.
       if(!w->close())
         break;
+      // Close the corresponding document to remove its lock file
+      static_cast<KWordQuizApp *>(w)->document()->close();
     }
   }
 }
